local addon = MC
assert(addon, "MosphetCookiesOptions requires MosphetCookies.")

local module = addon:NewModule("Options")
addon.Options = module

local AC = LibStub("AceConfig-3.0")
local ACD = LibStub("AceConfigDialog-3.0")
local SharedMedia = LibStub("LibSharedMedia-3.0")

-- -----------------
--  Locals
-- -----------------
local pairs, ipairs, tinsert = pairs, ipairs, tinsert
local format, strupper, strlower, strsub, strfind = string.format, string.upper, string.lower, string.sub, string.find
local UnitIsPlayer = _G.UnitIsPlayer
local GetSpellInfo = _G.GetSpellInfo
local UnitClass = _G.UnitClass

local dbp
local unlocked
local options

function module:OnInitialize()
	dbp = MC.db.profile
	self:RegisterOptions()
	
	options.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(MC.db)
	options.args.profile.order = 500
	
	AC:RegisterOptionsTable("MosphetCookies", options)
	ACD:SetDefaultSize("MosphetCookies", 400, 500)
end

function module:RegisterOptions()
	options = {
		name = "Mosphet Cookies",
		handler = addon,
		type = "group",
		args = {
			inline_enabled = {
				order = 1,
				type = "toggle",
				name = "Enabled",
				desc = "Enable or disable addon.",
				descStyle = "inline",
				set = function(info,v)
					if addon:IsEnabled() then
						addon:Disable()
						dbp.enabled = false
					else
						addon:Enable()
						dbp.enabled = true
					end
				end,
				get = function() return addon:IsEnabled() end,
			},
			inline_lock = {
				order = 2,
				type = "toggle",
				name = "Locked",
				desc = "Lock or unlock anchor.",
				descStyle = "inline",
				set = function(info,v) addon:ToggleAnchor(); unlocked = not unlocked end,
				get = function(info) return not unlocked end,
			},
			inline_versionheader = {
				name = ("Version: %d"):format(addon.version),
				type = "header",
				order = 3,
			},
			
		},
	}
	
	options.args.general = {
		name = "General",
		type = "group",
		order = 1,
		args = {
			--[[Font = {
				order = 1,
				type = "select",
				name = "Main Font",
				desc = "Font for the spell and cast display",
				values = {
					todo = "Todo",
				},
				values = SM:HashTable("font"),
				dialogControl = "LSM30_Font",
				set = function(info,v) dbp.fontface = v; addon:UpdateFont() end,
				get = function() return dbp.fontface end,
			},]]
			FontSize = {
				order = 2,
				type = "range",
				name = "Font Size",
				desc = "Select a font size (between 8 and 36)",
				min = 8,
				max = 26,
				step = 1,
				set = function(info,v) dbp.fontsize = v; addon:UpdateFont() end,
				get = function() return dbp.fontsize end,
			},
			TextJustification = {
				order = 3,
				type = "select",
				name = "Justification",
				desc = "Select the anchor justification",
				values = {
					LEFT = "Left",
					CENTER = "Center",
					RIGHT = "Right",
				},
				set = function(info,v) dbp.justification = v; addon:UpdateJustification(v) end,
				get = function() return dbp.justification end,
			},			
		},
	}
	
	options.args.displays = {
		name = "Display Options",
		type = "group",
		order = 2,
		args = {
			desc1 = {
				name = "Hunter Displays",
				type = "header",
				order = 1,
			},
			aimed = {
				type = "toggle",
				name = "Display Aimed Shot cast time.",
				order = 2,
				width = "full",
				set = function(info,v) dbp.aimed = v end,
				get = function() return dbp.aimed end,
			},
			steady = {
				type = "toggle",
				name = "Display Steady Shot cast time.",
				order = 3,
				width = "full",
				set = function(info,v) dbp.steady = v end,
				get = function() return dbp.steady end,
			},
			cobra = {
				type = "toggle",
				name = "Display Cobra Shot cast time.",
				order = 4,
				width = "full",
				set = function(info,v) dbp.cobra = v end,
				get = function() return dbp.cobra end,
			},
			hastev = {
				type = "toggle",
				name = "Display current Haste value.",
				order = 5,
				width = "full",
				set = function(info,v) dbp.hastev = v end,
				get = function() return dbp.hastev end,
			},
			hastep = {
				type = "toggle",
				name = "Display current Haste Percent.",
				order = 6,
				width = "full",
				set = function(info,v) dbp.hastep = v end,
				get = function() return dbp.hastep end,
			},
			clear1 = {
				type = "description",
				name = "\n",
				order = 7,
				width = "full",
			},
			desc2 = {
				name = "Pet Displays",
				type = "header",
				order = 8,
			},
			petap = {
				type = "toggle",
				name = "Display pet attack power.",
				order = 9,
				width = "full",
				set = function(info,v) dbp.petap = v end,
				get = function() return dbp.petap end,
			},
			rabid = {
				type = "toggle",
				name = "Display Rabid Stack count.",
				order = 10,
				width = "full",
				set = function(info,v) dbp.rabid = v end,
				get = function() return dbp.rabid end,
			},
		},
	}
	
	options.args.colours = {
		name = "Colours & Thresholds",
		type = "group",
		order = 3,
		args = {
			coming = {
				name = "Coming Soon",
				type = "header",
				order = 0,
			},
			derp = {
				type = "description",
				name = "This section of the options interface is something under works and will not work currently.",
				order = 0.5,
			},
			AimedDesc = {
				name = "Aimed Shot",
				type = "header",
				order = 1,
			},
			AimedThreshold = {
				order = 2,
				type = "input",
				name = "Threshold",
				desc = "Steady/Cobra Shot Threshold.",
				width = "full",
			},
			AimedColourAbove = {
				order = 3,
				type = "color",
				name = "Above Threshold",
				desc = "Font colour above the required Aimed Shot cast value",
				hasAlpha = true,
			},
			AimedColourBelow = {
				order = 4,
				type = "color",
				name = "Below Threshold",
				desc = "Font colour below the required Aimed Shot cast value",
				hasAlpha = true,
			},
			clear1 = {
				type = "description",
				name = "\n",
				order = 5,
				width = "full",
			},
			SteadyDesc = {
				name = "Steady/Cobra Shot",
				type = "header",
				order = 6,
			},
			SteadyThreshold = {
				order = 7,
				type = "input",
				name = "Threshold",
				desc = "Steady/Cobra Shot Threshold.",
				width = "full",
			},
			SteadyColourAbove = {
				order = 8,
				type = "color",
				name = "Above Threshold",
				desc = "Font colour above the required Aimed Shot cast value",
				hasAlpha = true,
			},
			SteadyColourBelow = {
				order = 9,
				type = "color",
				name = "Below Threshold",
				desc = "Font colour below the required Aimed Shot cast value",
				hasAlpha = true,
			},
		},
	}
	
	options.args.about = {
		name = "About",
		type = "group",
		order = 4,
		args = {
			addon_info = {
				type = "description",
				name = "Addon Author",
				order = 1,
			},
			authors_desc = {
				type = "description",
				name = format("%s <%s>", "|cffffd200Mosphet|r", "|cffffd200Inner Sanctum|r"),
				order = 2,
			},
			visit_desc = {
				type = "description",
				name = format("%s","|cffffd244http://www.innersanctumguild.com|r"),
				order = 3,
			},
		},
	}
end

function module:ToggleConfig() ACD[ACD.OpenFrames.MosphetCookies and "Close" or "Open"](ACD,"MosphetCookies") end